Method

Enum Method 

pub enum Method {
Show 15 variants MuslimWorldLeague, Egyptian, Karachi, UmmAlQura, Dubai, MoonsightingCommittee, NorthAmerica, Kuwait, Qatar, Singapore, Tehran, Turkey, France, Algeria, Other,
}
Provides preset configuration for a few authorities for calculating prayer times.

Variants



MuslimWorldLeague

Muslim World League. Standard Fajr time with an angle of 18°. Earlier Isha time with an angle of 17°.



Egyptian

Egyptian General Authority of Survey. Early Fajr time using an angle of 19.5° and a slightly earlier Isha time using an angle of 17.5°.



Karachi

University of Islamic Sciences, Karachi. A generally applicable method that uses standard Fajr and Isha angles of 18°.



UmmAlQura

Umm al-Qura University, Makkah. Uses a fixed interval of 90 minutes from Maghrib to calculate Isha, and a slightly earlier Fajr time with an angle of 18.5°. Note: you should add a +30 minute custom adjustment for Isha during Ramadan.



Dubai

Used in the UAE. Slightly earlier Fajr time and slightly later Isha time with angles of 18.2° for Fajr and Isha in addition to 3 minute offsets for sunrise, Dhuhr, Asr, and Maghrib.



MoonsightingCommittee

Method developed by Khalid Shaukat, founder of Moonsighting Committee Worldwide. Uses standard 18° angles for Fajr and Isha in addition to seasonal adjustment values. This method automatically applies the 1/7 approximation rule for locations above 55° latitude. Recommended for North America and the UK.



NorthAmerica

Also known as the ISNA method. Can be used for North America, but the MoonsightingCommittee method is preferable. Gives later Fajr times and early Isha times with angles of 15°.



Kuwait

Standard Fajr time with an angle of 18°. Slightly earlier Isha time with an angle of 17.5°.



Qatar

Same Isha interval as ummAlQura but with the standard Fajr time using an angle of 18°.



Singapore

Used in Singapore, Malaysia, and Indonesia. Early Fajr time with an angle of 20° and standard Isha time with an angle of 18°.



Tehran

Institute of Geophysics, University of Tehran. Early Isha time with an angle of 14°. Slightly later Fajr time with an angle of 17.7°. Calculates Maghrib based on the sun reaching an angle of 4.5° below the horizon.



Turkey

An approximation of the Diyanet method used in Turkey. This approximation is less accurate outside the region of Turkey.



France

Union des Organisations Islamiques de France (UOIF / ECFR). Standard Fajr time with an angle of 12° and Isha time with an angle of 12°.



Algeria

Algerian Ministry of Religious Affairs. Standard Fajr time with an angle of 18°, Isha time with an angle of 17°, and a +3 minute adjustment for Maghrib.



Other

Defaults to angles of 0°, should generally be used for making a custom method and setting your own values.

Implementations

Source

impl Method

pub fn parameters(&self) -> Parameters

Build the default Parameters for this calculation method.